@@ -5,6 +5,7 @@ import logging
 
 import swf.models
 import swf.models.decision
+import swf.exceptions
 
 from simpleflow import (
     executor,
@@ -310,7 +311,9 @@ class Executor(executor.Executor):
             return [decision], {}
 
         except Exception, err:
-            reason = 'Cannot replay the workflow "{}"'.format(err)
+            reason = 'Cannot replay the workflow {}({})'.format(
+                err.__class__.__name__,
+                err)
             logger.exception(reason)
 
             self.on_failure(reason)
